pub struct EguiBridge {
pub max_texture_bits: u8,
/* private fields */
}Expand description
Primary Egui Interface.
Fields
max_texture_bits: u8Number of bits allowed for texture size.
The texture will be 2^max_texture_size
Implementations
Sourceimpl EguiBridge
impl EguiBridge
pub fn get_max_texture_bits(&self) -> <u8 as GodotConvert>::Via
pub fn set_max_texture_bits( &mut self, max_texture_bits: <u8 as GodotConvert>::Via, )
Sourceimpl EguiBridge
APIs for spawning viewports.
impl EguiBridge
APIs for spawning viewports.
Key for every APIs are that any access to egui::Context triggers
Sourcepub fn setup_context(&self, setter: impl FnOnce(&Context) + 'static + Send)
pub fn setup_context(&self, setter: impl FnOnce(&Context) + 'static + Send)
Access to egui context at intra-frame. This will be called immediately if we’re already out of frame boundary(e.g. start..end), otherwise, queue it to be called later.
Sourcepub fn sync_root_region(&self, target: Option<Gd<Control>>)
pub fn sync_root_region(&self, target: Option<Gd<Control>>)
Synchronize root viewport’s region with given control. If None is given, it
unregisters synchronization.
Sourcepub fn current_frame(&self) -> &Context
pub fn current_frame(&self) -> &Context
Start a new frame (if required), and return context which you can draw with.
This is very default way of using EGUI, and anything you draw upon this will be
shown below the spawned root canvas; EguiBridge
Use this when you want to draw widget every frame within process() function.
Caveats
- Cloning
egui::Contextand access it directly out of provided lifecycle is not recommneded. Please guarantee that you only access this context within main thread, right after callingcurrent_frame.
Panics
- Called from non main gameplay thread.
Sourcepub fn viewport_immediate<R>(
&self,
id: ViewportId,
builder: ViewportBuilder,
show: impl FnMut(&Context, ViewportClass) -> R,
) -> R
pub fn viewport_immediate<R>( &self, id: ViewportId, builder: ViewportBuilder, show: impl FnMut(&Context, ViewportClass) -> R, ) -> R
Render viewport for current frame.
This is shortcut to following code.
let id = ViewportId::from_hash("123");
let builder = ViewportBuilder::default();
bridge.current_frame().show_viewport_immediate(
id, builder, |ctx, viewport_class| {
// do something ...
}
);Panics
Sourcepub fn viewport_spawn<L>(
&self,
id: ViewportId,
builder: ViewportBuilder,
show: impl FnMut(&Context) -> L + 'static,
)where
L: Into<WidgetRetain>,
pub fn viewport_spawn<L>(
&self,
id: ViewportId,
builder: ViewportBuilder,
show: impl FnMut(&Context) -> L + 'static,
)where
L: Into<WidgetRetain>,
Spawn new viewport, which renders provided callback at the start of next frame. This is thread-safe, however, you should call exactly once per gameplay frame to ensure viewport is persisted correctly.
This is inherently a shortcut to following code.
let id = ViewportId::from_hash("123");
let builder = ViewportBuilder::default();
bridge.egui_start().show_viewport_deferred(
id, builder, move |ctx, viewport_class| {
// do something ...
// Viewport will be retained as long as you
true
}
);Sourcepub fn register_render_callback_first<L>(
&self,
priority: i32,
widget: impl FnEguiDraw<L>,
)where
L: Into<WidgetRetain>,
pub fn register_render_callback_first<L>(
&self,
priority: i32,
widget: impl FnEguiDraw<L>,
)where
L: Into<WidgetRetain>,
Registers callback for widget rendering at frame start.
See also FnEguiDrawExt decorator for every method with signature
impl FnMut(&egui::Context) -> impl Into<WidgetRetain> + 'static
Callbacks registered with lower priority will be called earlier.
Sourcepub fn register_render_callback_last<L>(
&self,
priority: i32,
widget: impl FnEguiDraw<L>,
)where
L: Into<WidgetRetain>,
pub fn register_render_callback_last<L>(
&self,
priority: i32,
widget: impl FnEguiDraw<L>,
)where
L: Into<WidgetRetain>,
Registers callback for widget rendering at frame end.
See also FnEguiDrawExt decorator for every method with signature
impl FnMut(&egui::Context) -> impl Into<WidgetRetain> + 'static
Callbacks registered with lower priority will be called earlier.
Sourcepub fn viewport_spawn_as_child(
&self,
_id: ViewportId,
_parent: Gd<Control>,
_builder: ViewportBuilder,
_show: impl FnOnce(&Context) -> WidgetRetain + 'static,
)
pub fn viewport_spawn_as_child( &self, _id: ViewportId, _parent: Gd<Control>, _builder: ViewportBuilder, _show: impl FnOnce(&Context) -> WidgetRetain + 'static, )
Spawn new viewport as child of existing node. If specified parent node is behind other node, the input may work naturally as the egui surface always intercepts any GUI input. It is advised to use this method for any node that lays over any other GUI nodes, which makes all egui rendering appear always top of the other GUI nodes.
Sourcepub fn attach_node_to_viewport(
&self,
_id: ViewportId,
node: Gd<Node>,
) -> Result<(), Gd<Node>>
pub fn attach_node_to_viewport( &self, _id: ViewportId, node: Gd<Node>, ) -> Result<(), Gd<Node>>
Attach given node to given viewport’s window.
TODO: Implement this!